ipyvanish
===============================

version number: 0.0.1
author: Bradley McElroy

Overview
--------

A python package that can be installed with pip.

Installation / Usage
--------------------

To install use pip:

    $ pip install ipyvanish


Or clone the repo:

    $ git clone https://github.com/limx0/ipyvanish.git
    $ python setup.py install

Example
-------

Poll for all servers
`$ ipyvanish poll`

Or for specific country / city (or multiple) via `--countries` or `--cities`

`$ ipyvanish poll --countries=[Australia, Canada]`